import customtkinter as ctk
from tkinter import StringVar, Text
from DataBaseManager import get_random_row, search_row_by_name, add_dinosaur, conn

# Initialize the application
app = ctk.CTk()
app.geometry("800x800")
app.title("PaleoPedia")
app.iconbitmap("Logo.ico")


# Configure grid layout for the main window
app.grid_columnconfigure(0, weight=1)
app.grid_columnconfigure(1, weight=1)
app.grid_columnconfigure(2, weight=1)
app.grid_columnconfigure(3, weight=1)
app.grid_rowconfigure(0, weight=0)
app.grid_rowconfigure(1, weight=1)
app.grid_rowconfigure(2, weight=0)
app.grid_rowconfigure(3, weight=0)

# Variables
search_var = StringVar()
name_var = StringVar()
description_var = StringVar()


# Function to update the main frame with random dinosaur info
def update_random_dino():
    random_row = get_random_row()
    main_frame_text.delete("1.0", ctk.END)
    if random_row:
        main_frame_text.insert(ctk.END,
                               f"Random Dinosaur:\nID: {random_row[0]}\nName: {random_row[1]}\nDescription: {random_row[2]}")
    else:
        main_frame_text.insert(ctk.END, "No data found.")


# Function to update the main frame with search result
def update_search_result():
    search_name = search_var.get()
    search_result = search_row_by_name(search_name)
    main_frame_text.delete("1.0", ctk.END)
    if search_result:
        main_frame_text.insert(ctk.END,
                               f"Search Result for {search_name}:\nID: {search_result[0]}\nName: {search_result[1]}\nDescription: {search_result[2]}")
    else:
        main_frame_text.insert(ctk.END, f"No results found for {search_name}.")


# Function to add a new dinosaur
def add_new_dinosaur():
    name = name_var.get()
    description = description_var.get()
    if name and description:
        add_dinosaur(name, description)
        name_var.set("")
        description_var.set("")
        update_random_dino()  # Optionally update the random dino display after adding a new one


# Widgets
search_entry = ctk.CTkEntry(app, textvariable=search_var, width=200, height=30)
search_entry.grid(row=0, column=2, padx=5, pady=5, sticky="nsew")

search_button = ctk.CTkButton(app, text="Search", width=100, height=30, command=update_search_result)
search_button.grid(row=0, column=1, padx=5, pady=5, sticky="nsew")

main_frame = ctk.CTkFrame(app)
main_frame.grid(row=1, column=0, columnspan=4, padx=10, pady=10, sticky="nsew")

# Text widget inside the main frame to display text
main_frame_text = Text(main_frame, wrap='word')
main_frame_text.pack(expand=True, fill='both')

random_page_button = ctk.CTkButton(app, text="Random page", width=150, height=40, command=update_random_dino)
random_page_button.grid(row=2, column=0, padx=10, pady=10, sticky="nsew")

name_entry = ctk.CTkEntry(app, textvariable=name_var, width=200, height=30)
name_entry.grid(row=2, column=2, padx=10, pady=10, sticky="nsew")

description_entry = ctk.CTkEntry(app, textvariable=description_var, width=150, height=30)
description_entry.grid(row=2, column=3, padx=10, pady=10, sticky="nsew")

update_db_button = ctk.CTkButton(app, text="Update DB", width=150, height=40, command=add_new_dinosaur)
update_db_button.grid(row=3, column=2, columnspan=2, padx=10, pady=10, sticky="nsew")

main_frame.grid_rowconfigure(0, weight=1)
main_frame.grid_columnconfigure(0, weight=1)

# Main loop
app.mainloop()

conn.close()
